@@ -42,6 +42,16 @@ class FlavorList(task_manager.Task):
         return client.nova_client.flavors.list()
 
 
+class FlavorCreate(task_manager.Task):
+    def main(self, client):
+        return client.nova_client.flavors.create(**self.args)
+
+
+class FlavorDelete(task_manager.Task):
+    def main(self, client):
+        return client.nova_client.flavors.delete(**self.args)
+
+
 class ServerList(task_manager.Task):
     def main(self, client):
         return client.nova_client.servers.list(**self.args)
@@ -495,3 +505,33 @@ class EndpointList(task_manager.Task):
 class EndpointDelete(task_manager.Task):
     def main(self, client):
         return client.keystone_client.endpoints.delete(**self.args)
+
+
+# IdentityDomain and not Domain because Domain is a DNS concept
+class IdentityDomainCreate(task_manager.Task):
+    def main(self, client):
+        return client.keystone_client.domains.create(**self.args)
+
+
+# IdentityDomain and not Domain because Domain is a DNS concept
+class IdentityDomainList(task_manager.Task):
+    def main(self, client):
+        return client.keystone_client.domains.list()
+
+
+# IdentityDomain and not Domain because Domain is a DNS concept
+class IdentityDomainGet(task_manager.Task):
+    def main(self, client):
+        return client.keystone_client.domains.get(**self.args)
+
+
+# IdentityDomain and not Domain because Domain is a DNS concept
+class IdentityDomainUpdate(task_manager.Task):
+    def main(self, client):
+        return client.keystone_client.domains.update(**self.args)
+
+
+# IdentityDomain and not Domain because Domain is a DNS concept
+class IdentityDomainDelete(task_manager.Task):
+    def main(self, client):
+        return client.keystone_client.domains.delete(**self.args)
