@@ -198,16 +198,19 @@ class TestFloatingIP(base.TestCase):
             self.mock_floating_ip_new_rep['floatingip']['floating_ip_address'],
             ip['floating_ip_address'])
 
+    @patch.object(OpenStackCloud, 'keystone_session')
     @patch.object(OpenStackCloud, '_neutron_list_floating_ips')
     @patch.object(OpenStackCloud, 'search_networks')
     @patch.object(OpenStackCloud, 'has_service')
     def test_available_floating_ip_existing(
             self, mock_has_service, mock_search_networks,
-            mock__neutron_list_floating_ips):
+            mock__neutron_list_floating_ips, mock_keystone_session):
         mock_has_service.return_value = True
         mock_search_networks.return_value = [self.mock_get_network_rep]
         mock__neutron_list_floating_ips.return_value = \
             [self.mock_floating_ip_new_rep['floatingip']]
+        mock_keystone_session.get_project_id.return_value = \
+            '4969c491a3c74ee4af974e6d800c62df'
 
         ip = self.client.available_floating_ip(network='my-network')
 
@@ -215,6 +218,7 @@ class TestFloatingIP(base.TestCase):
             self.mock_floating_ip_new_rep['floatingip']['floating_ip_address'],
             ip['floating_ip_address'])
 
+    @patch.object(OpenStackCloud, 'keystone_session')
     @patch.object(OpenStackCloud, '_neutron_create_floating_ip')
     @patch.object(OpenStackCloud, '_neutron_list_floating_ips')
     @patch.object(OpenStackCloud, 'search_networks')
@@ -222,12 +226,14 @@ class TestFloatingIP(base.TestCase):
     def test_available_floating_ip_new(
             self, mock_has_service, mock_search_networks,
             mock__neutron_list_floating_ips,
-            mock__neutron_create_floating_ip):
+            mock__neutron_create_floating_ip, mock_keystone_session):
         mock_has_service.return_value = True
         mock_search_networks.return_value = [self.mock_get_network_rep]
         mock__neutron_list_floating_ips.return_value = []
         mock__neutron_create_floating_ip.return_value = \
             self.mock_floating_ip_new_rep['floatingip']
+        mock_keystone_session.get_project_id.return_value = \
+            '4969c491a3c74ee4af974e6d800c62df'
 
         ip = self.client.available_floating_ip(network='my-network')
 
