@@ -59,6 +59,8 @@ class FakeServer(object):
                              'version': 4}]}
     flavor = {'id': '101'}
     image = {'id': '471c2475-da2f-47ac-aba5-cb4aa3d546f5'}
+    accessIPv4 = ''
+    accessIPv6 = ''
 
 
 class TestMeta(testtools.TestCase):
@@ -122,14 +124,31 @@ class TestMeta(testtools.TestCase):
         }]
         mock_search_networks.return_value = [{'id': 'test-net-id'}]
 
-        srv = fakes.FakeServer(
-            id='test-id', name='test-name', status='ACTIVE')
+        srv = meta.obj_to_dict(fakes.FakeServer(
+            id='test-id', name='test-name', status='ACTIVE'))
         ip = meta.get_server_external_ipv4(
             cloud=shade.openstack_cloud(), server=srv)
 
         self.assertEqual(PUBLIC_V4, ip)
         self.assertFalse(mock_get_server_ip.called)
 
+    def test_get_server_external_ipv4_neutron_accessIPv4(self):
+        srv = meta.obj_to_dict(fakes.FakeServer(
+            id='test-id', name='test-name', status='ACTIVE',
+            accessIPv4=PUBLIC_V4))
+        ip = meta.get_server_external_ipv4(
+            cloud=shade.openstack_cloud(), server=srv)
+
+        self.assertEqual(PUBLIC_V4, ip)
+
+    def test_get_server_external_ipv4_neutron_accessIPv6(self):
+        srv = meta.obj_to_dict(fakes.FakeServer(
+            id='test-id', name='test-name', status='ACTIVE',
+            accessIPv6=PUBLIC_V6))
+        ip = meta.get_server_external_ipv6(server=srv)
+
+        self.assertEqual(PUBLIC_V6, ip)
+
     @mock.patch.object(shade.OpenStackCloud, 'has_service')
     @mock.patch.object(shade.OpenStackCloud, 'search_ports')
     @mock.patch.object(meta, 'get_server_ip')
@@ -140,8 +159,8 @@ class TestMeta(testtools.TestCase):
         mock_search_ports.side_effect = neutron_exceptions.NotFound()
         mock_get_server_ip.return_value = PUBLIC_V4
 
-        srv = fakes.FakeServer(
-            id='test-id', name='test-name', status='ACTIVE')
+        srv = meta.obj_to_dict(fakes.FakeServer(
+            id='test-id', name='test-name', status='ACTIVE'))
         ip = meta.get_server_external_ipv4(
             cloud=shade.openstack_cloud(), server=srv)
 
@@ -159,9 +178,9 @@ class TestMeta(testtools.TestCase):
         mock_get_server_ip.return_value = None
         mock_is_globally_routable_ipv4.return_value = True
 
-        srv = fakes.FakeServer(
+        srv = meta.obj_to_dict(fakes.FakeServer(
             id='test-id', name='test-name', status='ACTIVE',
-            addresses={'test-net': [{'addr': PUBLIC_V4}]})
+            addresses={'test-net': [{'addr': PUBLIC_V4}]}))
         ip = meta.get_server_external_ipv4(
             cloud=shade.openstack_cloud(), server=srv)
 
@@ -180,9 +199,9 @@ class TestMeta(testtools.TestCase):
         mock_get_server_ip.return_value = None
         mock_is_globally_routable_ipv4.return_value = False
 
-        srv = fakes.FakeServer(
+        srv = meta.obj_to_dict(fakes.FakeServer(
             id='test-id', name='test-name', status='ACTIVE',
-            addresses={'test-net': [{'addr': PRIVATE_V4}]})
+            addresses={'test-net': [{'addr': PRIVATE_V4}]}))
         ip = meta.get_server_external_ipv4(
             cloud=shade.openstack_cloud(), server=srv)
 
@@ -191,7 +210,7 @@ class TestMeta(testtools.TestCase):
         self.assertTrue(mock_is_globally_routable_ipv4.called)
 
     def test_get_server_external_ipv6(self):
-        srv = fakes.FakeServer(
+        srv = meta.obj_to_dict(fakes.FakeServer(
             id='test-id', name='test-name', status='ACTIVE',
             addresses={
                 'test-net': [
@@ -199,7 +218,7 @@ class TestMeta(testtools.TestCase):
                     {'addr': PUBLIC_V6, 'version': 6}
                 ]
             }
-        )
+        ))
         ip = meta.get_server_external_ipv6(srv)
         self.assertEqual(PUBLIC_V6, ip)
 
@@ -233,15 +252,20 @@ class TestMeta(testtools.TestCase):
         self.assertEqual(new_list[0]['value'], 0)
         self.assertEqual(new_list[1]['value'], 1)
 
+    @mock.patch.object(shade.meta, 'get_server_external_ipv6')
     @mock.patch.object(shade.meta, 'get_server_external_ipv4')
-    def test_basic_hostvars(self, mock_get_server_external_ipv4):
+    def test_basic_hostvars(
+            self, mock_get_server_external_ipv4,
+            mock_get_server_external_ipv6):
         mock_get_server_external_ipv4.return_value = PUBLIC_V4
+        mock_get_server_external_ipv6.return_value = PUBLIC_V6
 
         hostvars = meta.get_hostvars_from_server(
             FakeCloud(), meta.obj_to_dict(FakeServer()))
         self.assertNotIn('links', hostvars)
         self.assertEqual(PRIVATE_V4, hostvars['private_v4'])
         self.assertEqual(PUBLIC_V4, hostvars['public_v4'])
+        self.assertEqual(PUBLIC_V6, hostvars['public_v6'])
         self.assertEqual(PUBLIC_V4, hostvars['interface_ip'])
         self.assertEquals(FakeCloud.region_name, hostvars['region'])
         self.assertEquals(FakeCloud.name, hostvars['cloud'])
